@@ -1,5 +1,5 @@
 # bind global variables
-if(getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci", "lower.ci", "ia", "..density.."))
+if (getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci", "lower.ci", "ia", "..density.."))
 
 
 
@@ -18,7 +18,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci",
 #'         with decimales may result in unexpected behaviour.
 #' 
 #' @param varCount The variable which frequencies should be plotted.
-#' @param title Title of diagram as string. Example: \code{title=c("my title")}.
+#' @param title Title of diagram as string. Example: \code{title = "my title"}.
 #'          Use \code{NULL} to automatically detect variable names that will be used as title
 #'          (see \code{\link[sjmisc]{set_var_labels}}) for details).
 #' @param weightBy A weight factor that will be applied to weight all cases from \code{varCount}.
@@ -33,27 +33,26 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci",
 #'          Default is \code{"none"}, so categories are not sorted by frequency. Use \code{"asc"} or
 #'          \code{"desc"} for sorting categories ascending or descending in relation to the frequencies.
 #' @param type Specifies the type of distribution plot that will be plotted.
-#'          \itemize{
-#'            \item \code{"bar"}, \code{"bars"} or \code{"b"} for simple bars (the default setting).
-#'            \item \code{"dots"} or \code{"dot"} for a dot plot.
-#'            \item \code{"h"}, \code{"hist"} or \code{"histogram"} for a histogram.
-#'            \item \code{"line"}, \code{"lines"} or \code{"l"} for a histogram with filled area with line.
-#'            \item \code{"dens"}, \code{"d"} or \code{"density"} for a density plot.
-#'            \item \code{"box"}, \code{"boxplot"} or \code{"boxplots"} for box plots.
-#'            \item \code{"v"} or \code{"violin"} for violin plots.
+#'          \describe{
+#'            \item{\code{"bar"}}{or \code{"bars"} or \code{"b"} for simple bars (the default setting)}
+#'            \item{\code{"dots"}}{or \code{"dot"} for a dot plot}
+#'            \item{\code{"h"}}{or \code{"hist"} or \code{"histogram"} for a histogram}
+#'            \item{\code{"line"}}{or \code{"lines"} or \code{"l"} for a histogram with filled area with line}
+#'            \item{\code{"dens"}}{or \code{"d"} or \code{"density"} for a density plot}
+#'            \item{\code{"box"}}{or \code{"boxplot"} or \code{"boxplots"} for box plots}
+#'            \item{\code{"v"}}{or \code{"violin"} for violin plots}
 #'            }
-#' @param geom.colors User defined color for geoms, e.g. \code{geom.colors="#0080ff"}.
-#' @param geom.size The size of the geoms, depending on the \code{type} of the plot. Note that 
-#'          bar and bin widths mostly need smaller values than dot sizes (i.e. if \code{type} is
-#'          \code{"dots"}).
+#' @param geom.colors user defined color for geoms, e.g. \code{geom.colors = "#0080ff"}.
+#' @param geom.size size of geoms, depending on the plot \code{type}. Note that 
+#'          bar and bin widths mostly need smaller values than dot sizes (i.e. if \code{type = "dots"}).
 #' @param axisLabels.x Labels for the x-axis breaks.
-#'          Example: \code{axisLabels.x=c("Label1", "Label2", "Label3")}.
-#'          Note: If you use the \code{\link[sjmisc]{read_spss}} function and the \code{\link[sjmisc]{get_val_labels}} function, you receive a
+#'          Example: \code{axisLabels.x = c("Label1", "Label2", "Label3")}. \cr
+#'          \strong{Note:} If you use the \code{\link[sjmisc]{read_spss}} function and the \code{\link[sjmisc]{get_val_labels}} function, you receive a
 #'          list object with label string. The labels may also be passed as list object. They will be coerced
 #'          to character vector automatically.
 #' @param interactionVarLabels Labels for the x-axis breaks when having interaction variables included.
 #'          These labels replace the \code{axisLabels.x}. Only applies, when using box or violin plots
-#'          (i.e. \code{"type"} is \code{"box"} or \code{"violin"}) and \code{interactionVar} is not \code{NULL}.
+#'          (i.e. \code{type} is \code{"box"} or \code{"violin"}) and \code{interactionVar} is not \code{NULL}.
 #'          Example: See \code{axisLabels.x}.
 #' @param axisLimits.y A numeric vector of length two, defining lower and upper axis limits
 #'          of the y scale. By default, this parameter is set to \code{NULL}, i.e. the 
@@ -65,7 +64,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci",
 #' @param gridBreaksAt Sets the breaks on the y axis, i.e. at every n'th position a major
 #'          grid is being printed.
 #' @param innerBoxPlotWidth The width of the inner box plot that is plotted inside of violin plots. Only applies 
-#'          if \code{type} is \code{"violin"}. Default value is 0.15
+#'          if \code{type = "violin"}. Default value is 0.15
 #' @param innerBoxPlotDotSize Size of mean dot insie a violin plot. Applies only when \code{type} is set to \code{"violin"} or \code{"box"}.
 #' @param expand.grid If \code{TRUE}, the plot grid is expanded, i.e. there is a small margin between
 #'          axes and plotting region. Default is \code{FALSE}.
@@ -75,8 +74,8 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci",
 #'          count values are removed.
 #' @param showPercentageValues If \code{TRUE} (default), percentage values are be plotted to each bar, if \code{FALSE},
 #'          percentage-values are removed.
-#' @param showAxisLabels.x Whether x axis labels (category names) should be shown or not.
-#' @param showAxisLabels.y Whether y axis labels (count values) should be shown or not.
+#' @param showAxisLabels.x Whether x-axis labels (category names) should be shown or not.
+#' @param showAxisLabels.y Whether y-axis labels (count values) should be shown or not.
 #' @param showCI logical, whether or not confidence intervals should be plotted. Only applies to \code{type = "dots"}
 #'          or \code{type = "bars"}.
 #' @param error.bar.color Color of confidence interval bars (error bars). Only applies to \code{type = "bars"}. In case
@@ -107,13 +106,13 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci",
 #'          applies if \code{showNormalCurve} is \code{TRUE}.
 #' @param normalCurveAlpha Specify the transparancy (alpha value) of the normal curve. Only
 #'          applies if \code{showNormalCurve} is \code{TRUE}.
-#' @param axisTitle.x A label for the x axis. useful when plotting histograms with metric scales where no category labels
-#'          are assigned to the x axis. By default, \code{""} is used, i.e. no title
+#' @param axisTitle.x label for the x-axis. useful when plotting histograms with metric scales where no category labels
+#'          are assigned to the x-axis. By default, \code{""} is used, i.e. no title
 #'          is printed.
 #'          Use \code{NULL} to automatically detect variable names that will be used as title
 #'          (see \code{\link[sjmisc]{set_var_labels}}) for details).
-#' @param axisTitle.y A label for the y axis. useful when plotting histograms with metric scales where no category labels
-#'          are assigned to the y axis. By default, \code{""} is used, i.e. no title
+#' @param axisTitle.y label for the y-axis. useful when plotting histograms with metric scales where no category labels
+#'          are assigned to the y-axis. By default, \code{""} is used, i.e. no title
 #'          is printed.
 #'          Use \code{NULL} to automatically detect variable names that will be used as title
 #'          (see \code{\link[sjmisc]{set_var_labels}}) for details).
@@ -128,10 +127,10 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci",
 #'          If you set \code{startAxisAt} to 1, you may have zero counts if the lowest value of \code{varCount}
 #'          is larger than 1 and hence no bars plotted for these values in such cases.
 #' @param autoGroupAt A value indicating at which length of unique values of \code{varCount} the variable
-#'          is automatically grouped into smaller units (see \code{group_var}). If \code{varCount} has large 
+#'          is automatically grouped into smaller units (see \code{\link[sjmisc]{group_var}}). If \code{varCount} has large 
 #'          numbers of unique values, too many bars for the graph have to be plotted. Hence it's recommended 
 #'          to group such variables. For example, if \code{autoGroupAt} is 50, i.e. if \code{varCount} has 50 and more unique values 
-#'          it will be grouped using \code{group_var} with \code{groupsize="auto"} parameter. By default, 
+#'          it will be grouped using \code{group_var} with \code{groupsize = "auto"} parameter. By default, 
 #'          the maximum group count is 30. However, if \code{autoGroupAt} is less than 30, \code{autoGroupAt} 
 #'          groups are built. Default value for \code{autoGroupAt} is \code{NULL}, i.e. auto-grouping is off.
 #' @param coord.flip If \code{TRUE}, the x and y axis are swapped. Default is \code{FALSE}.
@@ -149,21 +148,21 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci",
 #' # ---------------
 #' # boxplot
 #' # ---------------
-#' sjp.frq(ChickWeight$weight, type="box")
+#' sjp.frq(ChickWeight$weight, type = "box")
 #' 
 #' # ---------------
 #' # histogram
 #' # ---------------
-#' sjp.frq(discoveries, type="hist", showMeanIntercept=TRUE)
+#' sjp.frq(discoveries, type = "hist", showMeanIntercept = TRUE)
 #' # histogram with minimal theme and w/o labels
-#' sjp.frq(discoveries, type="hist",
-#'         showMeanIntercept=TRUE,
-#'         showValueLabels=FALSE)
+#' sjp.frq(discoveries, type = "hist",
+#'         showMeanIntercept = TRUE,
+#'         showValueLabels = FALSE)
 #'         
 #' # ---------------
 #' # violin plot
 #' # ---------------
-#' sjp.frq(ChickWeight$weight, type="v")
+#' sjp.frq(ChickWeight$weight, type = "v")
 #' 
 #' # ---------------
 #' # bar plot
@@ -173,7 +172,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci",
 #' # ---------------
 #' # bar plot with EUROFAMCARE sample dataset
 #' # dataset was importet from an SPSS-file, using:
-#' # efc <- read_spss("efc.sav", enc="UTF-8")
+#' # efc <- sjmisc::read_spss("efc.sav", enc = "UTF-8")
 #' # ---------------
 #' library(sjmisc)
 #' data(efc)
@@ -181,36 +180,36 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci",
 #' efc.var <- get_var_labels(efc)
 #' # you may use sjp.setTheme here to change axis textangle
 #' sjp.frq(as.factor(efc$e15relat), 
-#'         title=efc.var[['e15relat']],
-#'         axisLabels.x=efc.val['e15relat'])
+#'         title = efc.var[['e15relat']],
+#'         axisLabels.x = efc.val['e15relat'])
 #' 
 #' # bar plot with EUROFAMCARE sample dataset
 #' # grouped variable
 #' ageGrp <- group_var(efc$e17age)
 #' ageGrpLab <- group_labels(efc$e17age)
 #' sjp.frq(ageGrp,
-#'         title=efc.var[['e17age']],
-#'         axisLabels.x=ageGrpLab)
+#'         title = efc.var[['e17age']],
+#'         axisLabels.x = ageGrpLab)
 #' 
 #' # ---------------
 #' # box plots with interaction variable
 #' # the following example is equal to the function call
-#' # sjp.grpfrq(efc$e17age, efc$e16sex, type="box")
+#' # sjp.grpfrq(efc$e17age, efc$e16sex, type = "box")
 #' # ---------------
 #' sjp.frq(efc$e17age,
-#'         title=paste(efc.var[['e17age']], "by", efc.var[['e16sex']]),
-#'         interactionVar=efc$e16sex,
-#'         interactionVarLabels=efc.val['e16sex'],
-#'         type="box")
+#'         title = paste(efc.var[['e17age']], 
+#'                       "by", 
+#'                       efc.var[['e16sex']]),
+#'         interactionVar = efc$e16sex,
+#'         interactionVarLabels = efc.val['e16sex'],
+#'         type = "box")
 #' 
 #' # -------------------------------------------------
 #' # auto-detection of value labels and variable names
 #' # -------------------------------------------------
-#' efc <- set_var_labels(efc, get_var_labels(efc))
-#' 
 #' # negative impact scale, ranging from 7-28, assuming that
 #' # variable scale (lowest value) starts with 1
-#' sjp.frq(efc$neg_c_7, startAxisAt=1)
+#' sjp.frq(efc$neg_c_7, startAxisAt = 1)
 #' 
 #' # negative impact scale, ranging from 7-28, using
 #' # automatic detection of start index of x-axis
@@ -313,13 +312,13 @@ sjp.frq <- function(varCount,
   # We have several options to name the histrogram type
   # Here we will reduce it to a unique value
   # --------------------------------------------------------
-  if (type=="b" || type=="bar") type <- c("bars")
-  if (type=="dot") type <- c("dots")
-  if (type=="h" || type=="hist") type <- c("histogram")
-  if (type=="d" || type=="density") type <- c("dens")
-  if (type=="l" || type=="lines") type <- c("line")
-  if (type=="box" || type=="boxplot") type <- c("boxplots")
-  if (type=="v") type <- c("violin")
+  if (type == "b" || type == "bar") type <- c("bars")
+  if (type == "dot") type <- c("dots")
+  if (type == "h" || type == "hist") type <- c("histogram")
+  if (type == "d" || type == "density") type <- c("dens")
+  if (type == "l" || type == "lines") type <- c("line")
+  if (type == "box" || type == "boxplot") type <- c("boxplots")
+  if (type == "v") type <- c("violin")
   if (expand.grid == TRUE) {
     expand.grid <- waiver()
   } else {
@@ -338,16 +337,16 @@ sjp.frq <- function(varCount,
   if (!is.null(autoGroupAt) && length(unique(varCount)) >= autoGroupAt) {
     message(sprintf("Variable has %i unique values and was grouped...", length(unique(varCount))))
     # check for default auto-group-size or user-defined groups
-    agcnt <- ifelse (autoGroupAt < 30, autoGroupAt, 30)
+    agcnt <- ifelse(autoGroupAt < 30, autoGroupAt, 30)
     # group axis labels
     axisLabels.x <- sjmisc::group_labels(varCount, 
-                                 groupsize = "auto", 
-                                 autoGroupCount = agcnt)
+                                         groupsize = "auto", 
+                                         autoGroupCount = agcnt)
     # group variable
     varCount <- sjmisc::group_var(varCount, 
-                          groupsize = "auto", 
-                          asNumeric = TRUE, 
-                          autoGroupCount = agcnt)
+                                  groupsize = "auto", 
+                                  asNumeric = TRUE, 
+                                  autoGroupCount = agcnt)
   }
   # --------------------------------------------------------
   # unlist labels
@@ -393,7 +392,7 @@ sjp.frq <- function(varCount,
   if (!is.null(title)) {
     # if we have weighted values, say that in diagram's title
     if (!is.null(weightByTitleString)) {
-      title <- paste(title, weightByTitleString, sep="")
+      title <- paste(title, weightByTitleString, sep = "")
     }
     title <- sjmisc::word_wrap(title, breakTitleAt)    
   }
@@ -423,15 +422,15 @@ sjp.frq <- function(varCount,
   # If we have a histogram, caluclate means of groups
   # --------------------------------------------------------
   if (is.null(weightBy)) {
-    mittelwert <- mean(varCount, na.rm=TRUE)
+    mittelwert <- mean(varCount, na.rm = TRUE)
   } else {
-    mittelwert <- weighted.mean(varCount, weightBy, na.rm=TRUE)
+    mittelwert <- weighted.mean(varCount, weightBy, na.rm = TRUE)
   }
-  stddev <- sd(varCount, na.rm=TRUE)
+  stddev <- sd(varCount, na.rm = TRUE)
   # --------------------------------------------------------
   # If we have boxplots, use different data frame structure
   # --------------------------------------------------------
-  if (type=="boxplots" || type=="violin") {
+  if (type == "boxplots" || type == "violin") {
     if (is.null(interactionVar)) {
       mydat <- na.omit(data.frame(cbind(grp = 1, 
                                         frq = varCount, 
@@ -487,7 +486,7 @@ sjp.frq <- function(varCount,
     geob <- geom_bar(stat = "identity", 
                      width = geom.size, 
                      fill = geom.colors)
-  } else if (type=="dots") {
+  } else if (type == "dots") {
     geob <- geom_point(size = geom.size, fill = geom.colors)
   }
   if (!showAxisLabels.x) axisLabels.x <- c("")
@@ -724,7 +723,7 @@ sjp.frq <- function(varCount,
       # base constructor
       if (hist.skipZeros) {
         x <- na.omit(varCount)
-        if (geom.size<round(diff(range(x)) / 50)) message("Using very small binwidth. Consider adjusting \"geom.size\"-parameter.")
+        if (geom.size < round(diff(range(x)) / 50)) message("Using very small binwidth. Consider adjusting \"geom.size\"-parameter.")
         hist.dat <- data.frame(x)
         baseplot <- ggplot(mydat)
         basehist <- geom_histogram(data = hist.dat, 
@@ -838,9 +837,9 @@ sjp.frq <- function(varCount,
   # -------------------------------------
   # return results
   # -------------------------------------
-  invisible (structure(class = "sjpfrq",
-                       list(plot = baseplot,
-                            mydf = mydat)))
+  invisible(structure(class = "sjpfrq",
+                      list(plot = baseplot,
+                           mydf = mydat)))
 }
 
 
@@ -859,11 +858,11 @@ freqYlim <- function(var) {
   len <- max(var)
   
   anzahl <- 5
-  while (len>=(10*anzahl)) {
+  while (len >= (10 * anzahl)) {
     anzahl <- anzahl + 5
   }
-  correct <- 10+(floor(log10(len))-1)
-  return (correct*anzahl)  
+  correct <- 10 + (floor(log10(len)) - 1)
+  return(correct * anzahl)  
 }
 
 histYlim <- function(var) {
@@ -871,29 +870,26 @@ histYlim <- function(var) {
   # also den höchsten Wert einer Variablenausprägung
   len <- max(table(var))
   
-  if (len<100) {
+  if (len < 100) {
     anzahl <- 10
-  }
-  else {
+  } else {
     anzahl <- 100
   }
   
   li <- ceiling(len/anzahl)
-  if ((li %% 2) == 1) {
-    li <- li+1
-  }
-  
-  retval <- li*anzahl
-  
-  return (retval)
+  if ((li %% 2) == 1) li <- li + 1
+
+  return(li * anzahl)
 }
 
 # usage:
 # df<-insertRowToDF(df,5,c(16,0)); # inserting the values (16,0) after the 5th row
-insertRowToDF<-function(X,index_after,vector_to_insert){
+insertRowToDF <- function(X, index_after, vector_to_insert){
   stopifnot(length(vector_to_insert) == ncol(X)) # to check valid row to be inserted
-  X<-rbind(X[1:index_after,],vector_to_insert,X[(index_after+1):nrow(X),])
-  row.names(X)<-1:nrow(X)
-  return (X)
+  X <- rbind(X[1:index_after,],
+             vector_to_insert,
+             X[(index_after + 1):nrow(X), ])
+  row.names(X) <- 1:nrow(X)
+  return(X)
 }
 
