@@ -1,5 +1,5 @@
 # bind global variables
-if(getRversion() >= "2.15.1") utils::globalVariables(c("beta", "lower", "upper", "p", "pa", "shape"))
+if (getRversion() >= "2.15.1") utils::globalVariables(c("beta", "lower", "upper", "p", "pa", "shape"))
 
 #' @title Plot beta coefficients of multiple fitted lm's
 #' @name sjp.lmm
@@ -10,7 +10,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("beta", "lower", "upper",
 #' @param ... One or more fitted lm-objects. May also be a \code{\link{list}}-object with 
 #'          fitted models, instead of separating each model with comma. See examples.
 #' @param title Diagram's title as string.
-#'          Example: \code{title=c("my title")}
+#'          Example: \code{title = "my title"}
 #' @param labelDependentVariables Labels of the dependent variables of all fitted models
 #'          which have been used as first parameter(s), provided as char vector.
 #' @param legendDepVarTitle A character vector used for the title of the dependent variable's legend.
@@ -22,8 +22,8 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("beta", "lower", "upper",
 #'          Default is \code{"Model"}.
 #' @param axisLabels.y Labels of the predictor variables (independent vars, betas) that are used for labelling the
 #'          axis. Passed as vector of strings.
-#'          Example: \code{axisLabels.y=c("Label1", "Label2", "Label3")}
-#'          Note: If you use the \code{\link[sjmisc]{read_spss}} function and the \code{\link[sjmisc]{get_val_labels}} function, you receive a
+#'          Example: \code{axisLabels.y = c("Label1", "Label2", "Label3")} \cr
+#'          \strong{Note:} If you use the \code{\link[sjmisc]{read_spss}} function and the \code{\link[sjmisc]{get_val_labels}} function, you receive a
 #'          \code{list} object with label strings. The labels may also be passed as list object. They will be coerced
 #'          to character vector automatically.
 #' @param showAxisLabels.y Whether beta names (predictor labels) should be shown or not.
@@ -51,10 +51,9 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("beta", "lower", "upper",
 #'            \item If not specified, the qualitative \code{"Dark2"} color brewer palette will be used.
 #'            \item If \code{"gs"}, a greyscale will be used.
 #'            \item If \code{geom.colors} is any valid color brewer palette name, the related \href{http://colorbrewer2.org}{color brewer} palette will be used. Use \code{display.brewer.all()} from the \code{RColorBrewer} package to view all available palette names.
+#'            \item Else specify your own color values as vector (e.g. \code{geom.colors = c("#f00000", "#00ff00", "#0080ff")}).
 #'            }
-#'          Else specify your own color values as vector (e.g. \code{geom.colors=c("#f00000", "#00ff00", "#0080ff")}).
-#' @param nsAlpha The alpha level (transparancy) of non significant predicors. Points and error bars
-#'          are affected by this value and plotted with a slight transparancy. Default is 1.
+#' @param fade.ns if \code{TRUE}, non significant estimates will be printed in slightly faded colors.
 #' @param usePShapes If \code{TRUE}, significant levels are distinguished by different point shapes and a related
 #'          legend is plotted. Default is \code{FALSE}.
 #' @param interceptLineType The linetype of the intercept line (zero point). Default is \code{2} (dashed line).
@@ -89,7 +88,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("beta", "lower", "upper",
 #' fit3 <- lm(tot_sc_e ~ c160age + c12hour + c161sex + c172code, data = efc)
 #' 
 #' # plot multiple models
-#' sjp.lmm(fit1, fit2, fit3, facet.grid = TRUE)
+#' sjp.lmm(fit1, fit2, fit3, facet.grid = TRUE, fade.ns = FALSE)
 #' 
 #' # plot multiple models with legend labels and point shapes instead of value  labels
 #' sjp.lmm(fit1, fit2, fit3,
@@ -102,8 +101,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("beta", "lower", "upper",
 #'                                      "Services used"),
 #'          showValueLabels = FALSE,
 #'          showPValueLabels = FALSE,
-#'          usePShapes = TRUE,
-#'          nsAlpha = 0.3)
+#'          usePShapes = TRUE)
 #' 
 #' # plot multiple models from nested lists parameter
 #' all.models <- list()
@@ -131,8 +129,8 @@ sjp.lmm <- function(...,
                      gridBreaksAt=NULL,
                      geom.size=3,
                      geom.spacing=0.4,
-                     geom.colors="Dark2",
-                     nsAlpha=1,
+                     geom.colors="Set1",
+                     fade.ns=TRUE,
                      usePShapes=FALSE,
                      interceptLineType=2,
                      interceptLineColor="grey70",
@@ -337,6 +335,10 @@ sjp.lmm <- function(...,
       geom_point(size = geom.size, position = position_dodge(-geom.spacing))
   }
   # --------------------------------------------------------
+  # fade non-significant estimates?
+  # --------------------------------------------------------
+  nsAlpha <- ifelse(fade.ns == TRUE, 0.3, 1.0)
+  # --------------------------------------------------------
   # continue with errorbars, p-value-label and intercept line
   # --------------------------------------------------------
   plotHeader <- plotHeader +
