@@ -9,7 +9,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("OR", "lower", "upper", "
 #' @param ... One or more fitted glm-objects. May also be a \code{\link{list}}-object with 
 #'          fitted models, instead of separating each model with comma. See examples.
 #' @param title Diagram's title as string.
-#'          Example: \code{title=c("my title")}
+#'          Example: \code{title = "my title"}
 #' @param labelDependentVariables Labels of the dependent variables of all fitted models
 #'          which have been used as first parameter(s), provided as char vector.
 #' @param legendDepVarTitle A character vector used for the title of the dependent variable's legend.
@@ -21,15 +21,15 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("OR", "lower", "upper", "
 #'          Default is \code{"Model"}.
 #' @param axisLabels.y Labels of the predictor variables (independent vars, odds) that are used for labelling the
 #'          axis. Passed as vector of strings.
-#'          Example: \code{axisLabels.y=c("Label1", "Label2", "Label3")}
-#'          Note: If you use the \code{\link[sjmisc]{read_spss}} function and the \code{\link[sjmisc]{get_val_labels}} function, you receive a
+#'          Example: \code{axisLabels.y = c("Label1", "Label2", "Label3")} \cr
+#'          \strong{Note:} If you use the \code{\link[sjmisc]{read_spss}} function and the \code{\link[sjmisc]{get_val_labels}} function, you receive a
 #'          \code{list} object with label strings. The labels may also be passed as list object. They will be coerced
 #'          to character vector automatically.
 #' @param showAxisLabels.y Whether odds names (predictor labels) should be shown or not.
 #' @param axisTitle.x A label ("title") for the x axis.
 #' @param axisLimits Defines the range of the axis where the beta coefficients and their confidence intervalls
 #'          are drawn. By default, the limits range from the lowest confidence interval to the highest one, so
-#'          the diagram has maximum zoom. Use your own values as 2-value-vector, for instance: \code{limits=c(-0.8,0.8)}.
+#'          the diagram has maximum zoom. Use your own values as 2-value-vector, for instance: \code{limits = c(-0.8, 0.8)}.
 #' @param breakTitleAt Wordwrap for diagram title. Determines how many chars of the title are displayed in
 #'          one line and when a line break is inserted into the title
 #' @param breakLabelsAt Wordwrap for diagram labels. Determines how many chars of the category labels are displayed in 
@@ -54,10 +54,9 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("OR", "lower", "upper", "
 #'            \item If not specified, the qualitative \code{"Dark2"} color brewer palette will be used.
 #'            \item If \code{"gs"}, a greyscale will be used.
 #'            \item If \code{geom.colors} is any valid color brewer palette name, the related \href{http://colorbrewer2.org}{color brewer} palette will be used. Use \code{display.brewer.all()} from the \code{RColorBrewer} package to view all available palette names.
+#'            \item Else specify your own color values as vector (e.g. \code{geom.colors = c("#f00000", "#00ff00", "#0080ff")}).
 #'            }
-#'          Else specify your own color values as vector (e.g. \code{geom.colors=c("#f00000", "#00ff00", "#0080ff")}).
-#' @param nsAlpha The alpha level (transparancy) of non significant predicors. Points and error bars
-#'          are affected by this value and plotted with a slight transparancy. Default is 1.
+#' @param fade.ns if \code{TRUE}, non significant estimates will be printed in slightly faded colors.
 #' @param usePShapes If \code{TRUE}, significant levels are distinguished by different point shapes and a related
 #'          legend is plotted. Default is \code{FALSE}.
 #' @param interceptLineType The linetype of the intercept line (zero point). Default is \code{2} (dashed line).
@@ -98,7 +97,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("OR", "lower", "upper", "
 #'               family = binomial(link = "logit"))
 #' 
 #' # plot multiple models
-#' sjp.glmm(fitOR1, fitOR2, fitOR3, facet.grid = TRUE)
+#' sjp.glmm(fitOR1, fitOR2, fitOR3, facet.grid = TRUE, fade.ns = FALSE)
 #' 
 #' # plot multiple models with legend labels and point shapes instead of value  labels
 #' sjp.glmm(fitOR1, fitOR2, fitOR3,
@@ -107,8 +106,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("OR", "lower", "upper", "
 #'                                      "Agriculture"),
 #'          showValueLabels = FALSE,
 #'          showPValueLabels = FALSE,
-#'          usePShapes = TRUE,
-#'          nsAlpha = 0.2)
+#'          usePShapes = TRUE)
 #' 
 #' # plot multiple models from nested lists parameter
 #' all.models <- list()
@@ -137,8 +135,8 @@ sjp.glmm <- function(...,
                     transformTicks=TRUE,
                     geom.size=3,
                     geom.spacing=0.4,
-                    geom.colors="Dark2",
-                    nsAlpha=1,
+                    geom.colors="Set1",
+                    fade.ns=TRUE,
                     usePShapes=FALSE,
                     interceptLineType=2,
                     interceptLineColor="grey70",
@@ -353,6 +351,10 @@ sjp.glmm <- function(...,
                  position = position_dodge(-geom.spacing))
   }
   # --------------------------------------------------------
+  # fade non-significant estimates?
+  # --------------------------------------------------------
+  nsAlpha <- ifelse(fade.ns == TRUE, 0.3, 1.0)
+  # --------------------------------------------------------
   # continue with errorbars, p-value-label and intercept line
   # --------------------------------------------------------
   plotHeader <- plotHeader +
