@@ -46,21 +46,7 @@
 #'          will be auto-detected depending on your platform (\code{"UTF-8"} for Unix and \code{"Windows-1252"} for
 #'          Windows OS). Change encoding if specific chars are not properly displayed (e.g.) German umlauts).
 #' @param CSS A \code{\link{list}} with user-defined style-sheet-definitions, according to the 
-#'          \href{http://www.w3.org/Style/CSS/}{official CSS syntax}. See return value \code{page.style} for details
-#'          of all style-sheet-classnames that are used in this function. Parameters for this list need:
-#'          \enumerate{
-#'            \item the class-names with \code{"css."}-prefix as parameter name and
-#'            \item each style-definition must end with a semicolon
-#'          } 
-#'          You can add style information to the default styles by using a + (plus-sign) as
-#'          initial character for the parameter attributes. Examples:
-#'          \itemize{
-#'            \item \code{css.table='border:2px solid red;'} for a solid 2-pixel table border in red.
-#'            \item \code{css.summary='font-weight:bold;'} for a bold fontweight in the summary row.
-#'            \item \code{css.arc='color:blue;'} for a blue text color each 2nd row.
-#'            \item \code{css.caption='+color:red;'} to add red font-color to the default table caption style.
-#'          }
-#'          See further examples below and the \href{http://www.strengejacke.de/sjPlot/sjtbasics}{sjPlot manual: sjt-basics}.
+#'          \href{http://www.w3.org/Style/CSS/}{official CSS syntax}. See 'Details'.
 #' @param useViewer If \code{TRUE}, the function tries to show the HTML table in the IDE's viewer pane. If
 #'          \code{FALSE} or no viewer available, the HTML table is opened in a web browser.
 #' @param no.output If \code{TRUE}, the html-output is neither opened in a browser nor shown in
@@ -80,6 +66,10 @@
 #'            }
 #'            for further use.
 #'
+#' @note See 'Notes' in \code{\link{sjt.frq}}.
+#'  
+#' @details See 'Details' in \code{\link{sjt.frq}}.
+#'
 #' @examples
 #' \dontrun{
 #' # init dataset
@@ -123,25 +113,25 @@
 #'                   css.arc = "color:blue;"))}
 #'
 #' @export
-sjt.df <- function (mydf,
-                    describe=TRUE,
-                    file=NULL,
-                    alternateRowColors=FALSE,
-                    orderColumn=NULL,
-                    orderAscending=TRUE,
-                    title=NULL,
-                    repeatHeader=FALSE,
-                    stringVariable="Variable",
-                    showType=FALSE,
-                    showRowNames=TRUE,
-                    showCommentRow=FALSE,
-                    commentString="No comment...",
-                    hideProgressBar=FALSE,
-                    encoding=NULL,
-                    CSS=NULL,
-                    useViewer=TRUE,
-                    no.output=FALSE,
-                    remove.spaces=TRUE) {
+sjt.df <- function(mydf,
+                   describe = TRUE,
+                   file = NULL,
+                   alternateRowColors = FALSE,
+                   orderColumn = NULL,
+                   orderAscending = TRUE,
+                   title = NULL,
+                   repeatHeader = FALSE,
+                   stringVariable = "Variable",
+                   showType = FALSE,
+                   showRowNames = TRUE,
+                   showCommentRow = FALSE,
+                   commentString = "No comment...",
+                   hideProgressBar = FALSE,
+                   encoding = NULL,
+                   CSS = NULL,
+                   useViewer = TRUE,
+                   no.output = FALSE,
+                   remove.spaces = TRUE) {
   # check encoding
   encoding <- get.encoding(encoding)
   # -------------------------------------
@@ -274,7 +264,7 @@ sjt.df <- function (mydf,
     else if (is.double(x)) vt <- c("numeric-double")
     else if (is.numeric(x)) vt <- c("numeric")
     else if (is.atomic(x)) vt <- c("atomic")
-    return (vt)
+    return(vt)
   }
   # -------------------------------------
   # header row
@@ -284,7 +274,7 @@ sjt.df <- function (mydf,
   if (showRowNames) page.content <- paste0(page.content, sprintf("    <th class=\"thead firsttablerow firsttablecol\">%s</th>\n", stringVariable))
   for (i in 1:colcnt) {
     # check variable type
-    vartype <- get.vartype(mydf[, i])
+    vartype <- get.vartype(mydf[[i]])
     # column names and variable as table headline
     page.content <- paste0(page.content, sprintf("    <th class=\"thead firsttablerow\">%s", cnames[i]))
     if (showType) page.content <- paste0(page.content, sprintf("<br>(%s)", vartype))
@@ -326,7 +316,7 @@ sjt.df <- function (mydf,
     if (showRowNames) page.content <- paste0(page.content, sprintf("    <th class=\"thead lasttablerow firsttablecol\">%s</th>\n", stringVariable))
     for (i in 1:colcnt) {
       # check variable type
-      vartype <- get.vartype(mydf[, i])
+      vartype <- get.vartype(mydf[[i]])
       # column names and variable as table headline
       page.content <- paste0(page.content, sprintf("    <th class=\"thead lasttablerow\">%s", cnames[i]))
       if (showType) page.content <- paste0(page.content, sprintf("<br>(%s)", vartype))
